function juliabw(c,N,Niter,xmin,xmax,ymin,ymax)
%
% juliabw(c,N,Niter,xmin,xmax,ymin,ymax)
%
% Disegna in nero i punti che vengono mandati all'infinito dalla mappa
% complessa z_{n+1} = z_n^2 + c, in bianco i rimanenti. Il bordo di questi
% domini e` l'insieme di Julia.
%
% Input:
%   c     costante complessa che definisce l'insieme
%   N     Numero di pixel in x e y
%   Niter Numero massimo di iterazioni
%   xmin  Ascissa minima nel plot
%   xmax  Ascissa massima nel plot
%   ymin  Ordinata minima nel plot
%   ymax  Ordinata massima nel plot
%
% N.B.: se dopo Niter iterazioni il punto non e` ancora all'infinito,
% allora viene dichiarato "bianco".
%
% Esempio
%
%   juliabw(-.08+.75*i,500,50,-1.3,1.3,-1.3,1.3);
%
% Altri esempi sono riportati alla fine di questo file. In GNU Octave
% e` possibile lanciarli con
%
% octave:1> demo juliabw
%
% Copyright (C) 2009 Simone Zuccher
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% Author:   Simone Zuccher <simone.zuccher@univr.it>
% Created:  04 Jul 2009
% Modified:

% Griglia
x = linspace(xmin,xmax,N);
y = linspace(ymin,ymax,N);
% Se z_n supera R, viene dichiarato "nero".
R = abs(c)+1;

% Matrice delle condizioni iniziali
[Re,Im] = meshgrid(x,y);
z = Re + 1i*Im;
zplot = ones(size(z));

% Ciclo
for i = 1:Niter
  condition = abs(z) > R;
  zplot(condition) = 0;
  z(~condition) = z(~condition).*z(~condition)+c;
end
% Plot
imagesc(x,y,zplot);
colormap(gray(2))
axis equal
axis off
%!demo
%! juliabw(0,500,300,-1.5,1.5,-1,1);
%!demo
%! phi = (1+sqrt(5))/2;
%! juliabw(1-phi,500,300,-1.5,1.5,-1,1);
%!demo
%! juliabw(-0.4+0.6i,500,300,-1.4,1.4,-1.2,1.2);
%!demo
%! juliabw(-0.7269+0.1889i,500,300,-1.5,1.5,-1,1);
%! figure
%! juliabw(-0.7269+0.1889i,500,300,0,0.8,-0.3,0.3);
%! figure
%! juliabw(-0.7269+0.1889i,500,300,0,0.1,-0.25,-0.18);
