function mandelbrotbw(N,Niter,xmin,xmax,ymin,ymax)
%
% mandelbrotbw(N,Niter,xmin,xmax,ymin,ymax)
%
% Disegna in bianco l'insieme di Mandelbrot della mappa complessa
%  z_{n+1} = z_n^2 + c.
%
% Input:
%   N     Numero di pixel in x e y
%   Niter Numero massimo di iterazioni
%   xmin  Ascissa minima nel plot
%   xmax  Ascissa massima nel plot
%   ymin  Ordinata minima nel plot
%   ymax  Ordinata massima nel plot
%
% N.B.: se dopo Niter iterazioni il punto non e` ancora all'infinito,
% allora viene dichiarato "bianco".
%
% Esempio
%
%   mandelbrotbw(100,100,-2,.6,-1.25,1.25)
%
% Altri esempi sono riportati alla fine di questo file. In GNU Octave
% e` possibile lanciarli con
%
% octave:1> demo mandelbrotbw
%
% Copyright (C) 2009 Simone Zuccher
%
% This program is free software; you can redistribute it and/or modify it
% under the terms of the GNU General Public License as published by
% the Free Software Foundation; either version 2, or (at your option)
% any later version.
%
% This program is distributed in the hope that it will be useful, but
% WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
% General Public License for more details.
%
% Author:   Simone Zuccher <simone.zuccher@univr.it>
% Created:  04 Jul 2009
% Modified:

% Griglia
x = linspace(xmin,xmax,N);
y = linspace(ymin,ymax,N);

% Matrice dei valori di c
[Re,Im] = meshgrid(x,y);
c = Re + 1i*Im;

% Matrice delle condizioni iniziali
z = zeros(size(c));
zplot = ones(size(c));

% Ciclo
for i = 1:Niter
  condition = abs(z) > 2;
  zplot(condition) = 0;
  z(~condition) = z(~condition).*z(~condition) + c(~condition);
end;
% Plot
imagesc(x,y,zplot);
colormap(gray(2))
axis equal
axis off
%!demo
%! mandelbrotbw(100,100,-2,.6,-1.25,1.25)
%!demo
%! mandelbrotbw(500,100,-1.9,.6,-1.25,1.25);
